@@ -20,7 +20,11 @@
 
 #include <string>
 
-class octave_i2c : public octave_base_value
+#ifdef HAVE_CONFIG_H
+#  include "../config.h"
+#endif
+
+class octave_i2c : public OCTAVE_BASE_CLASS
 {
 public:
   octave_i2c (void);
@@ -71,7 +75,7 @@ public:
   // 4.4+
   bool isobject (void) const { return true;}
 
-  octave_base_value * unique_clone (void) { count++; return this;}
+  octave_base_value * unique_clone (void) { OV_COUNT++; return this;}
 
  /**
   * overloaded methods to get properties
