@@ -1,5 +1,4 @@
-// Copyright (C) 2018   John Donoghue   <john.donoghue@ieee.org>
-// Copyright (C) 2014   John Donoghue   <john.donoghue@ieee.org>
+// Copyright (C) 2014-2020 John Donoghue   <john.donoghue@ieee.org>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,6 +20,10 @@
 #endif
 
 #ifdef BUILD_SERIAL
+#if HAVE_OCTAVE_LO_SYSDEP_H
+  #include <octave/lo-sysdep.h>
+#endif
+
 #include <iostream>
 #include <string>
 #include <algorithm>
@@ -29,31 +32,40 @@ using std::string;
 
 #include "serial_class.h"
 
-char *
-winerror (int err)
+std::string
+winerror ()
 {
-  static char errstring[100];
+  DWORD e;
 
-  if (err != 0) 
-    return strerror (err);
-  else
-   {
-     DWORD e;
+  e = GetLastError ();
 
-     e = GetLastError ();
-
-     if (FormatMessageA(FORMAT_MESSAGE_FROM_SYSTEM, 0, e,
-                        MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), errstring,
-                        sizeof(errstring)-1, 0) < 0)
-       {
-         errstring[0] = '\0';
-       }
+#if HAVE_OCTAVE_U8_TO_WSTRING
+  wchar_t errstring[100+1];
+  if (FormatMessageW(FORMAT_MESSAGE_FROM_SYSTEM, 0, e,
+                     MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), errstring,
+                     100, 0) == 0)
+    {
+      errstring[0] = '\0';
+    }
+  return octave::sys::u8_from_wstring (errstring);
+#else
+  char errstring[100+1];
+  if (FormatMessageA(FORMAT_MESSAGE_FROM_SYSTEM, 0, e,
+                     MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), errstring,
+                     100, 0) == 0)
+    {
+      errstring[0] = '\0';
     }
   return errstring;
+#endif
 }
 
+
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_serial, "octave_serial", "octave_serial");
 
+DEFBINOP_CLASS_OP (eq_serial_serial, serial, serial, ==)
+DEFBINOP_CLASS_OP (ne_serial_serial, serial, serial, !=)
+
 octave_serial::octave_serial(void)
 {
   static bool type_registered = false;
@@ -72,12 +84,19 @@ octave_serial::octave_serial(void)
 void 
 octave_serial::open (const std::string &path)
 {
-  fd = CreateFile(path.c_str (), GENERIC_READ|GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
   portPath = path;
   name = "Serial-" + path;
+
+  // use full extended port names if not already specified
+  std::string fullPath = path;
+  if (fullPath.length() > 0 && fullPath[0] != '\\')
+    fullPath = "\\\\.\\" + path;
+
+  fd = CreateFile(fullPath.c_str (), GENERIC_READ|GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
+    
   if (! fd_is_valid())
     {
-      error("serial: Error opening the interface: %s\n", winerror (errno));
+      error("serial: Error opening the interface: %s\n", winerror ().c_str ());
       return;
     }
 
@@ -93,7 +112,7 @@ octave_serial::open (const std::string &path)
   
   if(GetCommState (fd, &config) == FALSE)
     {
-      error ("serial: Failed to get terminal attributes: %s\n", winerror (errno));
+      error ("serial: Failed to get terminal attributes: %s\n", winerror ().c_str ());
       octave_serial::close ();
       return;
     }
@@ -108,7 +127,7 @@ octave_serial::open (const std::string &path)
 
   if (SetCommTimeouts(fd, &timeouts) == FALSE)
     {
-      error ("serial: Failed to disable timeouts: %s\n", winerror (errno));
+      error ("serial: Failed to disable timeouts: %s\n", winerror ().c_str ());
       octave_serial::close ();
       return;
     }
@@ -148,7 +167,7 @@ octave_serial::read(uint8_t *buf, unsigned int len)
 
       if(read_retval < 0)
         {
-          error ("srl_read: Error while reading: %s\n", winerror (errno));
+          error ("srl_read: Error while reading: %s\n", winerror ().c_str ());
           break;
         }
 
@@ -283,7 +302,7 @@ octave_serial::set_stopbits (unsigned short stopbits)
 
   if (SetCommState (fd,&config) == FALSE)
     {
-      error ("srl_stopbits: error setting stop bits: %s\n", winerror (errno));
+      error ("srl_stopbits: error setting stop bits: %s\n", winerror ().c_str ());
       return false;
     }
 
@@ -323,7 +342,7 @@ octave_serial::set_bytesize (unsigned short bytesize)
 
   if (SetCommState (fd, &config) == FALSE)
     {
-      error ("serial: error setting byte size: %s\n", winerror (errno));
+      error ("serial: error setting byte size: %s\n", winerror ().c_str ());
       return false;
     }
 
@@ -357,7 +376,7 @@ octave_serial::set_baudrate (unsigned int baud)
 
   if (SetCommState (fd, &config) == FALSE)
     {
-      error ("serial: error setting baud rate: %s\n", winerror (errno));
+      error ("serial: error setting baud rate: %s\n", winerror ().c_str ());
       config.BaudRate = old_baud;
       return false;
     }
@@ -404,6 +423,29 @@ octave_serial::flush (unsigned short queue_selector)
     return true;
 }
 
+int
+octave_serial::sendbreak (unsigned short ms)
+{
+  if (! fd_is_valid ())
+    {
+      error ("serial: Interface must be opened first...");
+      return -1;
+    }
+
+  if (ms > 5000)
+    ms = 5000;
+
+  if(SetCommBreak(fd) == TRUE)
+  {
+    Sleep(ms);
+
+    ClearCommBreak(fd);
+
+    return true;
+  }
+
+  return false;
+}
 
 int
 octave_serial::set_parity (const std::string &newparity)
@@ -445,7 +487,7 @@ octave_serial::set_parity (const std::string &newparity)
 
   if (SetCommState (fd, &config) == FALSE)
     {
-      error ("srl_parity: error setting parity: %s\n", winerror (errno));
+      error ("srl_parity: error setting parity: %s\n", winerror ().c_str ());
       return false;
     }
 
